@@ -8,6 +8,8 @@
 # in practice.
 
 import numpy as np
+from sklearn.cluster import AgglomerativeClustering
+from numpy import linalg as LA
 
 #================================================================================#
 
@@ -113,3 +115,4 @@ def CirSphSampling(N, lat_c=60, lon_range=[-180,180], sigma=0.01,
         np.sum((mu_c+pv_ax.reshape(1,3))**2, axis=1) - np.identity(3)
     pts_c_noise = np.dot(R, pts_c_noise.T).T
     return pts_c_noise
+
